import { useSupabaseAuthClient } from "../composables/useSupabaseAuthClient.mjs";
import { useSupabaseUser } from "../composables/useSupabaseUser.mjs";
import { useSupabaseToken } from "../composables/useSupabaseToken.mjs";
import { defineNuxtPlugin } from "#imports";
export default defineNuxtPlugin(async (nuxtApp) => {
  const user = useSupabaseUser();
  const authClient = useSupabaseAuthClient();
  if (!user.value) {
    const token = useSupabaseToken();
    if (token.value) {
      const { data: { user: supabaseUser }, error } = await authClient.auth.getUser(token.value);
      if (error) {
        token.value = null;
        user.value = null;
      } else {
        user.value = supabaseUser;
      }
    }
  }
  nuxtApp.hooks.hook("app:mounted", () => {
    authClient.auth.onAuthStateChange(async (event, session) => {
      if (session) {
        await setServerSession(event, session);
        const userResponse = session ? await authClient.auth.getUser() : null;
        user.value = userResponse ? userResponse.data.user : null;
      } else {
        user.value = null;
        await setServerSession(event, session);
      }
    });
  });
});
const setServerSession = (event, session) => {
  return $fetch("/api/_supabase/session", {
    method: "POST",
    body: { event, session }
  });
};
